<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>تم تمكين وضع الطائرة</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>تم تعطيل وضع الطائرة</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>تعطيل</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>تم تمكين</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>وضع الطائرة</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>إعدادات وضع الطائرة</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>وضع الطائرة</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>الأجهزة الخاصة بي</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>إعدادات البلوتوث</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>أطفئ</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>ايقاف</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>تشغيل</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>إعدادات البلوتوث</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 متصل</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>قيد الاتصال...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>البلوتوث</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>أطفئ</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>متصل بـ %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>غير متصل</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>إيقاف</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>البلوتوث</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>السطوع</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>إعدادات الشاشة</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>إعدادات الشاشة</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>السطوع</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>الأحد</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>الاثنين</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>الثلاثاء</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>الأربعاء</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>الخميس</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>الجمعة</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>السبت</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>إضافة تخطيط لوحة مفاتيح</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>الوقت والتاريخ</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>توقيت 12-ساعة</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>توقيت 24-ساعة</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>إعدادات الوقت</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>افتح التقويم</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>الاثنين</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>الثلاثاء</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>الأربعاء</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>الخميس</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>الجمعة</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>السبت</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>الأحد</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>الاثنين</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>الثلاثاء</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>الأربعاء</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>الخميس</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>جمعة</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>سبت</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>أحد</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>الأجهزة الأخرى</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>وضع عدم الإزعاج</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>إعدادات وضع عدم الإزعاج</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>تعطيل</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>تمكين</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>تم تمكين وضع عدم الإزعاج</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>تم تعطيل وضع عدم الإزعاج</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>وضع عدم الإزعاج</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>راحة العين</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>تم تمكين راحة العين</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>تم تعطيل راحة العين</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>إعدادات العرض</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>راحة العين</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>الموضوع</translation>
    </message>
    <message>
        <source>On</source>
        <translation> eingeschaltet</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>ausgeschaltet</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>الخفيف</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>الداكن</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>التلقائي</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>تعطيل راحة العين</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>تم تمكين راحة العين</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>إعدادات العرض</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>مظهر: فاتح</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>مظهر: داكن</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>مظهر: تلقائي</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>تأثير بصري</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>فاتح</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>داكن</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>تلقائي</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>المظهر</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>لا توجد رسائل</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>إعدادات الإخطار</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>الإخطارات</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>إيقاف وضع عدم الإزعاج</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>تفعيل وضع عدم الإزعاج</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>إخطار</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>لوحة المفاتيح الافتراضية</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>أداء عالٍ</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>متوازن</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>اقتصاد الطاقة</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>توازن الأداء</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>الطاقة</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>إعدادت الطاقة</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>السعة 1%, 2% دقيقة متبقية</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>السعة 1% ,2% ساعة 3% دقيقة متبقية</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>جاري الشحن 1%, 2% دقيقة للاكتمال</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>جاري الشحن 1%, 2% ساعة 3% دقيقة للاكتمال</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>السعة %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>قيد الشحن %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>السعة %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>السعة %1، مشحونة بالكامل</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>السعة %1، غير مشحونة</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>البطارية</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>التوصيل، يحسب وقت الشحن المقدر</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>حساب وقت الاستخدام المتبقي</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 دقيقة متبقية</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 ساعة %2 دقيقة متبقية</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>لا يتم الشحن</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>شحن كامل</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>التوصيل، %1 دقيقة حتى الشحن الكامل</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>التوصيل، %1 ساعة %2 دقيقة حتى الشحن الكامل</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>السعة %1، %2 ساعة متبقية</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 ساعة متبقية</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>التوصيل %1، %2 ساعة حتى الشحن الكامل</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>التوصيل %1، %1 ساعة حتى الشحن الكامل</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>إعدادات الطاقة</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>الموسيقى</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>غير معروف</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>إيقاف التشغيل</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>إسبات</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>وضع السكون</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>قفل</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>تسجيل الخروج</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>إعدادت الطاقة</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>إعادة التشغيل</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>التحديث والإغلاق</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>التحديث والإعادة التشغيل</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>إغلاق</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>تبديل المستخدم</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>اليوم</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>القمري</translation>
    </message>
    <message>
        <source>y</source>
        <translation>ي</translation>
    </message>
    <message>
        <source>m</source>
        <translation>م</translation>
    </message>
    <message>
        <source>d</source>
        <translation>يوم</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>الإثنين</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>الثلاثاء</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>الأربعاء</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>الخميس</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>الجمعة</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>السبت</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>الإحدى</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>يناير</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>فبراير</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>مارس</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>نيسان</translation>
    </message>
    <message>
        <source>May</source>
        <translation>ماي</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>يونيه</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>تموز</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>ايلول</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>اكتوبر</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>نوفمبر</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>كانون الاول</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>يناير</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>افتح التقويم</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>الاثنين</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>الثلاثاء</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>الاربعاء</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>الخميس</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>الجمعة</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>السبت</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>الاحد</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>الصوت</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>المخرجات</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>اعدادات الصوت</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>الصوت</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>غير مقفل</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>مغلق</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>اعدادات الصوت</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>لا يوجد ادوات صوت</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>الحجم %1</translation>
    </message>
</context>
</TS>